import React from "react";
import { cssMerge } from '../../utils/cssMerge';
import { slider, sliderCard, sliderCardImg, imgInsideSliderCardImg, sliderCardBody, sliderCardLabel, sliderCardHeadline } from "./Carousel.styles";
import styles from "./CarouselSlick.module.scss";

import Slider from "react-slick";

import Image from "next/image";
import { Button } from "../../molecules/Button";


interface CarouselProps {
    autoplay: boolean;
    autoplaySpeed?: number;
    slides?: CarouselSlideProps[];
}

interface CarouselSlideProps {
    image?: {
        src?: string;
        alt?: string;
    };
    label?: string;
    headline?: string;
    body?: string;
    button?: {
        label?: string;
        url?: string;
    }
}

import { ChevronLeft, ChevronRight } from "react-feather";

export const Carousel = ({ autoplay, autoplaySpeed, slides }: CarouselProps) => {
    const PrevArrow = (props: any) => {
        const { className, style, onClick } = props;
        return (
            <ChevronLeft className={className} style={style} onClick={onClick} />
        );
    };
    const NextArrow = (props: any) => {
        const { className, style, onClick } = props;
        return (
            <ChevronRight className={className} style={style} onClick={onClick} />
        );
    };

    const settings = {
        dots: true,
        slidesToShow: 1,
        slidesToScroll: 1,
        autoplay: autoplay,
        autoplaySpeed: autoplay ? autoplaySpeed : 0,
        prevArrow: <PrevArrow />,
        nextArrow: <NextArrow />,
    };

    if (!slides) return null;

    return (
        <div className={styles.solCarousel}>
            <div className="container">
                <div className={cssMerge(slider())} >
                    <Slider {...settings}>
                        {slides.map((slide, index) => (
                            <div className={sliderCard()} key={index}>
                                {slide.image && slide.image.src && (
                                    <div className={sliderCardImg()}>
                                        <Image src={slide.image.src} fill alt={slide.image.alt || ''} className={imgInsideSliderCardImg()} />
                                    </div>
                                )}

                                <div className={sliderCardBody()}>
                                    {slide.label && (
                                        <span className={cssMerge('text-uppercase smaller', sliderCardLabel())}>{slide.label}</span>
                                    )}
                                    {slide.headline && (
                                        <h2 className={cssMerge("h5 mt-3 fw-normal", sliderCardHeadline())}>{slide.headline}</h2>
                                    )}
                                    {slide.body && (
                                        <p className="mb-5 small">{slide.body}</p>
                                    )}
                                    {slide.button && slide.button.url && slide.button.label && (
                                        <Button {...slide.button}>
                                            {slide.button.label}
                                        </Button>
                                    )}
                                </div>
                            </div>
                        ))}
                    </Slider>
                </div>
            </div>
        </div>
    );
};